/*
 * Copyright (c) 2010, 2014, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/**
 * Array extension check
 *
 * @test
 * @run
 */

"use strict";
var a = [1,2,3];
Object.preventExtensions(a);
try {
    a[4] = 4;
    print(a);
} catch (e) {
    if (!(e instanceof TypeError)) {
	print("TypeError expected but got e");
    }
}

if (a[0] != 1) {
    throw "element 0 is wrong";
}
if (a[1] != 2) {
    throw "element 1 is wrong";
}
if (a[2] != 3) {
    throw "element 2 is wrong";
}

